# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _
from bottin.models import EntityProfile, Activity, Theme


@admin.register(Activity)
class ActivityAdmin(admin.ModelAdmin):
    list_display = ['name', ]
    prepopulated_fields = {'slug': ('name', )}


@admin.register(Theme)
class ThemeAdmin(admin.ModelAdmin):
    list_display = ['name', ]
    prepopulated_fields = {'slug': ('name', )}


@admin.register(EntityProfile)
class EntityProfileAdmin(admin.ModelAdmin):
    list_display = ['name', 'postal_code', 'city', 'email', ]
    fieldsets = (
        (_('Main'), {
            'fields': ('name', 'theme', 'activity')}),
        (_('Metadata'), {
            'fields': ('slug', 'activated')}),
        (_('Address'), {
            'fields': ('address', ('postal_code', 'city'))}),
        (_('Contact'), {
            'fields': ('contact', 'phone', ('email', 'website'))}),
        (_('Information'), {
            'fields': ('short_description', 'description', 'logo',
                       'timetable')}),
        (_('Location'), {
            'fields': (('longitude', 'latitude'),)}),
        )

    prepopulated_fields = {'slug': ('name', )}
