from django.db import models
from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _


class EntityActivatedManager(models.Manager):
    def get_queryset(self):
        return super(
            EntityActivatedManager,
            self).get_queryset().filter(activated=True)


class Theme(models.Model):
    name = models.CharField(_('Name'), max_length=150)
    description = models.TextField(_('Description'), blank=True)
    slug = models.SlugField(_('slug'), unique=True, max_length=256)

    def __str__(self):
        return self.name


class Activity(models.Model):
    name = models.CharField(_('Name'), max_length=150)
    description = models.TextField(_('Description'), blank=True)
    slug = models.SlugField(_('slug'), unique=True, max_length=256)

    def __str__(self):
        return self.name

    class Meta:
        verbose_name_plural = "activities"


class EntityProfile(models.Model):
    """
    Entity profile datas
    """
    name = models.CharField(_('Name'), max_length=150)
    theme = models.ManyToManyField(Theme)
    activity = models.ManyToManyField(Activity)
    address = models.TextField(_('Address'))
    postal_code = models.CharField(_('Postal code'), max_length=15)
    city = models.CharField(_('City'), max_length=100)
    contact = models.TextField(_('Contact'), blank=True)
    phone = models.CharField(_('Phone number'), max_length=25)
    email = models.CharField(_('Email'), max_length=256)
    website = models.CharField(_('Website'), max_length=256, blank=True)
    short_description = models.CharField(_('Short Description'),
                                         max_length=256, blank=True)
    description = models.TextField(_('Main Description'), blank=True)
    logo = models.ImageField(_('Logo'), upload_to='bottin', blank=True)
    timetable = models.TextField(_('Timetable'), blank=True)
    longitude = models.DecimalField(_('Longitude'), blank=True, max_digits=9,
                                    decimal_places=6, default=0.0)
    latitude = models.DecimalField(_('Latitude'), blank=True, max_digits=8,
                                   decimal_places=6, default=0.0)

    # metadata
    slug = models.SlugField(_('slug'), unique=True, max_length=256)
    activated = models.BooleanField(_("Activated"), default=True)

    # manager
    objects = models.Manager()
    activated_objects = EntityActivatedManager()

    def __str__(self):
        return self.name

    class Meta:
        verbose_name_plural = "entities"

    def get_absolute_url(self):
        return reverse('bottin-detailview', kwargs={'slug': self.slug})
